==> FSang18%27s%20Heroes%20v11.8.0.jar: data/fsang_hero/kubejs_scripts/grant_advancements.js <==
ServerEvents.tick(event => {
    const players = event.server.players;
    for (const player of players) {
        if (palladium.superpowers.hasSuperpower(player, 'fsang:matter_absorption')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_matter_absorption`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sandman')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_sandman_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:angel')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_angel`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:apocalypse')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_apocalypse`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:atlantean')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_atlantean`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:atlantean_sea_changed')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_atlantean2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine2')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine3')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:leech_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_leech_mutation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:colossus')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_colossus`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:colossus2')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_colossus2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:cryokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_cryokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:cyclops')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_cyclops`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:darwin')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_darwinism`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:electrokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_electrokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:vulcan')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_energy_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:eye_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_eyes`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:face_change')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_face_morph`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:gambit')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_gambit`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:havok')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_havok`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:human_torch')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_human_torch`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:invisibility')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_invinsibility`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:luck_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_luck`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sabretooth')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_lupine`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:magnetism')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_magnetism`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:mimicry')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_mimicry`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:negative_speedforce')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_negative_speedforce`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_leech')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_negative_speedforce2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:phasing')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_phasing`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:pyrokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_pyrokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:reality_warping')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_reality_warping`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:regenerative_healing')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_regenerative_healing`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:self_detonation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_self_detonation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:size_change')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_size_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sound_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_sound_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speed_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speed_mutation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_kingdom')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_speed')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_strength')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce4`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:tachyon')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce5`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_silk')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_cindy`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_jessica')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_jessica`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_miguel')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_miguel`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_miles')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_miles`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_kaine')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_kain`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:storm')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_storm`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier_winter_soldier')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier_red_skull')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:telekinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_telekinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:telepathy')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_telepathy`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:teleportation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_teleportation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:daredevil')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_daredevil`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:time')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_time`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:hulk')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_hulk_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_human')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_thraxan')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_brute')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna4`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_scout')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna5`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:radiant_black')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:break_radiant_black_hole`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:symbiote_natural')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_natural_symbiote`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:symbiote')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_symbiote_artificial`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:kaiju_no_8')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_kaiju_no_8`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:phoenix_force')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:find_phoenix_force`);
        }
        if (player.mainHandItem.id == 'fsang:amazon_artifact') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_amazon_artifact`);
        }
        if (player.mainHandItem.id == 'fsang:atlantean_artifact') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_atlantean_artifact`);
        }
        if (player.mainHandItem.id == 'fsang:spider_serum') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_spider_serum`);
        }
    }
});

==> FSang18%27s%20Heroes%20v11.8.2.jar: data/fsang_hero/kubejs_scripts/grant_advancements.js <==
ServerEvents.tick(event => {
    const players = event.server.players;
    for (const player of players) {
        if (palladium.superpowers.hasSuperpower(player, 'fsang:matter_absorption')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_matter_absorption`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:geokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_geokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:martian_green')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_martian_green`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sandman')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_sandman_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:angel')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_angel`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:apocalypse')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_apocalypse`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:atlantean')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_atlantean`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:atlantean_sea_changed')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_atlantean2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine2')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:wolverine3')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_bone_claws3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:leech_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_leech_mutation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:colossus')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_colossus`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:colossus2')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_colossus2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:cryokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_cryokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:cyclops')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_cyclops`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:darwin')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_darwinism`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:electrokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_electrokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:vulcan')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_energy_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:eye_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_eyes`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:face_change')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_face_morph`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:gambit')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_gambit`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:havok')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_havok`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:human_torch')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_human_torch`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:invisibility')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_invinsibility`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:luck_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_luck`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sabretooth')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_lupine`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:magnetism')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_magnetism`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:mimicry')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_mimicry`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:negative_speedforce')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_negative_speedforce`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_leech')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_negative_speedforce2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:phasing')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_phasing`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:pyrokinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_pyrokinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:reality_warping')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_reality_warping`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:regenerative_healing')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_regenerative_healing`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:self_detonation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_self_detonation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:size_change')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_size_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:sound_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_sound_manipulation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speed_mutation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speed_mutation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_kingdom')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_speed')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:speedforce_strength')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce4`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:tachyon')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_speedforce5`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_silk')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_cindy`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_jessica')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_jessica`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_miguel')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_miguel`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_miles')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_miles`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:spiderman_kaine')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_spiderman_kain`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:storm')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_storm`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier_winter_soldier')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:super_soldier_red_skull')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_super_soldier3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:telekinesis')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_telekinesis`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:telepathy')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_telepathy`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:teleportation')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_teleportation`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:daredevil')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_daredevil`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:time')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:got_time`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:hulk')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_hulk_dna`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_human')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna2`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_thraxan')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna3`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_brute')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna4`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:viltrumite_scout')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_viltrumite_dna5`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang:radiant_black')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:break_radiant_black_hole`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:symbiote_natural')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_natural_symbiote`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:symbiote')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_symbiote_artificial`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:kaiju_no_8')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang_secondary:get_kaiju_no_8`);
        }
        if (palladium.superpowers.hasSuperpower(player, 'fsang_secondary:phoenix_force')) {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:find_phoenix_force`);
        }
        if (player.mainHandItem.id == 'fsang:amazon_artifact') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_amazon_artifact`);
        }
        if (player.mainHandItem.id == 'fsang:atlantean_artifact') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:get_atlantean_artifact`);
        }
        if (player.mainHandItem.id == 'fsang:spider_serum') {
            player.server.runCommandSilent(`advancement grant ${player.username} only fsang:craft_spider_serum`);
        }
    }
});
